==> SPDMood_v4.01.tgz: SPDMood_v4.01/src/SPDMood.h <==
#ifndef SPDMOOD_H
#define SPDMOOD_H

#include <Rtypes.h>
#include <TString.h>
#include <pthread.h>

enum EMenuItemIDs {
  B_LOGIN2, B_DUMP2_START, B_DUMPN_START, DEADNOISY_START, UPLOADCOMMAND_START, 
  MOVIE_START, UPDATE_MASK, UPDATE_EQACTIVATE, UPDATE_SUPPRERROR, 
  CLOSE_SIDEVIEW, 

  B_LOGIN, B_DUMPC, B_DUMP2, B_DUMPN, B_DUMP1, 
  B_RESET_ERR_FLAG, B_UPDATE, B_SCREENSHOT, B_CLOSEALL, B_RESET, 

  B_SCREENSHOT2, B_LOGOUTYES, B_LOGOUTNO, 

  FILE_DUMPCONF, FILE_LOADCONF, FILE_DEFAULTCONF, FILE_SAVECONF, 
  FILE_SAVECONFAS, FILE_EXIT,

  CONF_CHANGESOURCE, CONF_TRIGMASKALL, CONF_EQACTIVATE, CONF_SUPPRERROR, 
  CONF_UPDATETIME, CONF_ADVEVCNTDUMPALL, CONF_CALIB, 

  OP_DEADNOISY, OP_DEADNOISY2, OP_MOVIE, 

  MASK_MASK, MASK_UNMASK, MASK_LOADDIR, MASK_SAVEDIR, MASK_CLEAR, 
  MASK_PRINTLIST, 

  LOGIN_INTERRUPT, FINISH_RUNNING, 
  APP_FORCE_CLOSE, 

  TESTTEST, TESTTEST2,

  NAN_NAN,

};

enum toolBarButtons {
  TOOL_BAR_BUTTON_AUTOUPDATE,
  TOOL_BAR_BUTTON_AUTORESET,
  TOOL_BAR_BUTTON_SKIPPIXEL,
  TOOL_BAR_BUTTON_SKIPCLUSTER,
  TOOL_BAR_BUTTON_TRYDISPERR,
  TOOL_BAR_BUTTON_STOPONERR,
  TOOL_BAR_BUTTON_SKIP_ADV_EVC_CHECK,
  TOOL_BAR_BUTTON_MINIEV_ID_CHECK
};

//!!!extern struct optionStruct {
//!!!  UInt_t aa_nbInRun_;
//!!!  UInt_t aa_runNb_;
//!!!
//!!!  Int_t  moodVersionFlag;
//!!!  Int_t  handleEventMin;
//!!!  Int_t  handleEventMax;
//!!!  TString uploadCommand2;
//!!!
//!!!  UInt_t eventType;          // DATE Options
//!!!  UInt_t monitoringPolicy;
//!!!  Bool_t monitorOffLine;
//!!!  Bool_t declareMonitor;
//!!!  Bool_t swap16;
//!!!  Bool_t swap32;
//!!!  Bool_t setNowait;
//!!!  TString dataSourceFullPath;
//!!!  TString dataSourceFullPathOnline;
//!!!  TString dataSourceFullPathOffline;
//!!!  Bool_t dataSourceOnline;
//!!!  TString nameOfMp;
//!!!  Bool_t multipleFiles;
//!!!
//!!!  Bool_t dumpInconsistent;
//!!!  Bool_t alerBeforeDumping;
//!!!    
//!!!  UInt_t dumpNr;
//!!!
//!!!  UInt_t deadLimit;
//!!!  UInt_t noisyLimit;
//!!!
//!!!  TString uploadCommand;
//!!!  Float_t updateTime;
//!!!
//!!!  TString movieName;
//!!!  UInt_t movieTotal;
//!!!  UInt_t movieRate;
//!!!  UInt_t movieDelay;
//!!!
//!!!  Bool_t eqActive[20];
//!!!  Int_t errorSuppr;
//!!!
//!!!  Bool_t rootMode;
//!!!  Bool_t advEvCntDumpAll;
//!!!  Bool_t globalOverlap;
//!!!  Bool_t multipleFileType;
//!!!
//!!!  Bool_t dataSourceOfflineList;
//!!!  TString dataSourceFullPathOfflineList;
//!!!
//!!!  Float_t safetyHoldTime;
//!!!  Float_t safetyContTime;
//!!!
//!!!  UInt_t stopRunEventNumber;
//!!!
//!!!
//!!!}o;




#endif

==> SPDMood_v4.04.tgz: SPDMood_v4.04/src/SPDMood.h <==
#ifndef SPDMOOD_H
#define SPDMOOD_H

#include <Rtypes.h>
#include <TString.h>
#include <pthread.h>

enum EMenuItemIDs {
  B_LOGIN2, B_DUMP2_START, B_DUMPN_START, DEADNOISY_START, UPLOADCOMMAND_START, 
  MOVIE_START, UPDATE_MASK, UPDATE_EQACTIVATE, UPDATE_SUPPRERROR, 
  CLOSE_SIDEVIEW, 

  B_LOGIN, B_DUMPC, B_DUMP2, B_DUMPN, B_DUMP1, 
  B_RESET_ERR_FLAG, B_UPDATE, B_SCREENSHOT, B_CLOSEALL, B_RESET, 

  B_SCREENSHOT2, B_LOGOUTYES, B_LOGOUTNO, 

  FILE_DUMPCONF, FILE_LOADCONF, FILE_DEFAULTCONF, FILE_SAVECONF, 
  FILE_SAVECONFAS, FILE_EXIT,

  CONF_CHANGESOURCE, CONF_TRIGMASKALL, CONF_EQACTIVATE, CONF_SUPPRERROR, 
  CONF_UPDATETIME, CONF_ADVEVCNTDUMPALL, CONF_CALIB, 

  OP_DEADNOISY, OP_DEADNOISY2, //!!!OP_GRIDCONNECT, 

  MASK_MASK, MASK_UNMASK, MASK_LOADDIR, MASK_SAVEDIR, MASK_CLEAR, 
  MASK_PRINTLIST, 

  LOGIN_INTERRUPT, FINISH_RUNNING, 
  APP_FORCE_CLOSE, 

  TESTTEST, TESTTEST2,

  NAN_NAN,

};

enum toolBarButtons {
  TOOL_BAR_BUTTON_AUTOUPDATE,
  TOOL_BAR_BUTTON_AUTORESET,
  TOOL_BAR_BUTTON_SKIPPIXEL,
  TOOL_BAR_BUTTON_SKIPCLUSTER,
  TOOL_BAR_BUTTON_TRYDISPERR,
  TOOL_BAR_BUTTON_STOPONERR,
  TOOL_BAR_BUTTON_SKIP_ADV_EVC_CHECK,
  TOOL_BAR_BUTTON_MINIEV_ID_CHECK
};

//!!!extern struct optionStruct {
//!!!  UInt_t aa_nbInRun_;
//!!!  UInt_t aa_runNb_;
//!!!
//!!!  Int_t  moodVersionFlag;
//!!!  Int_t  handleEventMin;
//!!!  Int_t  handleEventMax;
//!!!  TString uploadCommand2;
//!!!
//!!!  UInt_t eventType;          // DATE Options
//!!!  UInt_t monitoringPolicy;
//!!!  Bool_t monitorOffLine;
//!!!  Bool_t declareMonitor;
//!!!  Bool_t swap16;
//!!!  Bool_t swap32;
//!!!  Bool_t setNowait;
//!!!  TString dataSourceFullPath;
//!!!  TString dataSourceFullPathOnline;
//!!!  TString dataSourceFullPathOffline;
//!!!  Bool_t dataSourceOnline;
//!!!  TString nameOfMp;
//!!!  Bool_t multipleFiles;
//!!!
//!!!  Bool_t dumpInconsistent;
//!!!  Bool_t alerBeforeDumping;
//!!!    
//!!!  UInt_t dumpNr;
//!!!
//!!!  UInt_t deadLimit;
//!!!  UInt_t noisyLimit;
//!!!
//!!!  TString uploadCommand;
//!!!  Float_t updateTime;
//!!!
//!!!  TString movieName;
//!!!  UInt_t movieTotal;
//!!!  UInt_t movieRate;
//!!!  UInt_t movieDelay;
//!!!
//!!!  Bool_t eqActive[20];
//!!!  Int_t errorSuppr;
//!!!
//!!!  Bool_t rootMode;
//!!!  Bool_t advEvCntDumpAll;
//!!!  Bool_t globalOverlap;
//!!!  Bool_t multipleFileType;
//!!!
//!!!  Bool_t dataSourceOfflineList;
//!!!  TString dataSourceFullPathOfflineList;
//!!!
//!!!  Float_t safetyHoldTime;
//!!!  Float_t safetyContTime;
//!!!
//!!!  UInt_t stopRunEventNumber;
//!!!
//!!!
//!!!}o;




#endif
